pub enum InvokeType {
LendMut = 1,
Lend = 2,
Scalar = 4,
BlockingScalar = 5,
}Expand description
Indicates the type of Message that is sent when making a SendMessage syscall.
Variants
LendMut = 1
Mutably lend the buffer to the server
Lend = 2
Immutably lend
Scalar = 4
Send a scalar message to the server without blocking
BlockingScalar = 5
Send a scalar message to the server and wait for a reply