SyscallResult

Enum SyscallResult 

#[repr(usize)]
pub enum SyscallResult { Ok = 0, Error = 1, MemoryRange = 3, ConnectionId = 7, Message = 9, ThreadId = 10, Scalar1 = 14, Scalar2 = 15, MemoryReturned = 18, Scalar5 = 20, }
Copies of these invocation types here for when we’re running in environments without libxous.

Variants



Ok = 0

The operation completed successfully



Error = 1

An error was encountered, with the exact error stored in $a1



MemoryRange = 3

A slice with the offset in $a1 and the length in $a2



ConnectionId = 7

A u32 connection ID stored in $a1



Message = 9

A message was received



ThreadId = 10

A u32 thread id stored in $a1



Scalar1 = 14

One scalar value, stored in $a1



Scalar2 = 15

Two scalar values, stored in $a1 and $a2



MemoryReturned = 18

Memory that was returned from a syscall, with return values in $a1 and $a2



Scalar5 = 20

Five scalar values, stored in $a1..=$a5