connect

Function connect 

pub fn connect(address: ServerAddress) -> Result<Connection, Error>
Connects to a Xous server represented by the specified address.

The current thread will block until the server is available. Returns an error if the server cannot accept any more connections.