do_yield

Function do_yield 

pub fn do_yield()
Suspends the current thread and allow another thread to run. This thread may continue executing again immediately if there are no other threads available to run on the system.