raw_syscall

Function raw_syscall 

pub unsafe fn raw_syscall(
    a0: usize,
    a1: usize,
    a2: usize,
    a3: usize,
    a4: usize,
    a5: usize,
    a6: usize,
    a7: usize,
) -> (usize, usize, usize, usize, usize, usize, usize, usize)
Perform a raw syscall without checking the return value.

Safety: The safety of the function depends on the syscall passed in a0.