Skip to main content Crate xous_sys Copy item path Source Connection A representation of a connection to a Xous service. ServerAddress ThreadId Error A list of all known errors that may be returned by the Xous kernel. InvokeType Indicates the type of Message that is sent when making a SendMessage syscall. Limits Limits that can be passed to AdjustLimit ServerAddressError Syscall Indicates a particular syscall number as used by the Xous kernel. SyscallResult Copies of these invocation types here for when we’re running
in environments without libxous. adjust_limit Adjusts the given knob limit to match the new value new. The current value must
match the current in order for this to take effect. blocking_scalar Send 5 scalar arguments to a server and wait for a response.
If the server mailbox is full, will block until it is available. connect Connects to a Xous server represented by the specified address. disconnect ⚠ Attempts to disconnect from the specified Xous server. do_yield Suspends the current thread and allow another thread to run. This thread may
continue executing again immediately if there are no other threads available
to run on the system. exit Terminates the current process and returns the specified code to the parent process. join_thread Waits for the given thread to terminate and returns the exit code from that thread. lend Lend the buffer to the server. Blocks if the mailbox is full. lend_mut Mutably lend the buffer to the server, blocking if
the mailbox is full. raw_syscall ⚠ Perform a raw syscall without checking the return value. scalar Send 5 scalar values to the server, blocking if the mailbox is full. syscall ⚠ Perform a type-checked syscall and check the return value. thread_id Gets the current thread’s ID. try_blocking_scalar Attempt to send 5 scalar arguments to a server. Returns an error
if the server mailbox is full. try_connect Attempts to connect to a Xous server represented by the specified address. try_lend Attempt to lend the slice to the server. Returns an error if
the mailbox is full. try_lend_mut Attempt to mutably lend the buffer to the server.
Returns an error if the server’s mailbox is full. try_scalar Attempt to send 5 scalar values to the server.